prompt property
Prompt text displayed on the scanner screen. Defaults to empty string which hides the prompt label.
Implementation
final String prompt;
Prompt text displayed on the scanner screen. Defaults to empty string which hides the prompt label.
final String prompt;