CardUtils class

Constructors

CardUtils()

Properties

amex → RegExp
final
bCGlobal → RegExp
final
carteBlanc → RegExp
final
dinersClub → RegExp
final
discover → RegExp
final
hashCode → int
The hash code for this object.
no setterinherited
instaPayment → RegExp
final
jCB → RegExp
final
koreanLocalCard → RegExp
final
maestro → RegExp
final
mastercard → RegExp
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
solo → RegExp
final
unionPay → RegExp
final
unknown → RegExp
final
visa → RegExp
final

Methods

getCardIssuer(String cardNumber) → CardIssuer
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited